# frozen_string_literal: true

require 'countries/version'

require 'countries/iso3166'

require 'countries/mongoid' if defined?(Mongoid)
